| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
DataFrame.IO.Parquet.Dictionary
Synopsis
- data DictVals
- readDictVals :: ThriftType -> ByteString -> Int32 -> Maybe Int32 -> DictVals
- decodeRLEBitPackedHybrid :: Int -> ByteString -> ([Word32], ByteString)
Documentation
Constructors
| DBool (Vector Bool) | |
| DInt32 (Vector Int32) | |
| DInt64 (Vector Int64) | |
| DInt96 (Vector UTCTime) | |
| DFloat (Vector Float) | |
| DDouble (Vector Double) | |
| DText (Vector Text) |
readDictVals :: ThriftType -> ByteString -> Int32 -> Maybe Int32 -> DictVals Source #
Decode the values from a dictionary page.
The numVals argument is the entry count declared in the dictionary page
header. It is used to limit BOOLEAN decoding (1-bit-per-value encoding has
no natural delimiter).
The typeLength argument is only meaningful for FIXED_LEN_BYTE_ARRAY: it is
the byte-width of each individual dictionary entry, NOT the total number of
entries. Passing numVals here (the old behaviour) would cause it to be
misread as an element size, yielding a dictionary that is far too small.
decodeRLEBitPackedHybrid :: Int -> ByteString -> ([Word32], ByteString) Source #